Struct bgp_models::bgp::elem::BgpElem
source · pub struct BgpElem {Show 15 fields
pub timestamp: f64,
pub elem_type: ElemType,
pub peer_ip: IpAddr,
pub peer_asn: Asn,
pub prefix: NetworkPrefix,
pub next_hop: Option<IpAddr>,
pub as_path: Option<AsPath>,
pub origin_asns: Option<Vec<Asn>>,
pub origin: Option<Origin>,
pub local_pref: Option<u32>,
pub med: Option<u32>,
pub communities: Option<Vec<MetaCommunity>>,
pub atomic: Option<AtomicAggregate>,
pub aggr_asn: Option<Asn>,
pub aggr_ip: Option<IpAddr>,
}Expand description
BgpElem represents per-prefix BGP element.
The information is for per announced/withdrawn prefix.
Note: it consumes more memory to construct BGP elements due to duplicate information shared between multiple elements of one MRT record.
Fields
timestamp: f64elem_type: ElemTypepeer_ip: IpAddrpeer_asn: Asnprefix: NetworkPrefixnext_hop: Option<IpAddr>as_path: Option<AsPath>origin_asns: Option<Vec<Asn>>origin: Option<Origin>local_pref: Option<u32>med: Option<u32>communities: Option<Vec<MetaCommunity>>atomic: Option<AtomicAggregate>aggr_asn: Option<Asn>aggr_ip: Option<IpAddr>Trait Implementations
sourceimpl Ord for BgpElem
impl Ord for BgpElem
sourceimpl PartialEq<BgpElem> for BgpElem
impl PartialEq<BgpElem> for BgpElem
sourceimpl PartialOrd<BgpElem> for BgpElem
impl PartialOrd<BgpElem> for BgpElem
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read more